# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

#' @include PrestoResult.R
NULL

.dbGetRowCount <- function(res, ...) {
  return(res@query$fetchedRowCount())
}

#' @rdname PrestoResult-class
#' @importMethodsFrom DBI dbGetRowCount
#' @export
setMethod("dbGetRowCount", "PrestoResult", .dbGetRowCount)
